@@ -21,7 +21,6 @@
 #define KWALLETMANAGER_H
 #include <QtCore/QObject>
 #include <kxmlguiwindow.h>
-#include <QIcon>
 
 class KWalletManagerWidget;
 class KStatusNotifierItem;
@@ -36,7 +35,7 @@ class KWalletManager : public KXmlGuiWindow
     Q_CLASSINFO("D-Bus Interface", "org.kde.kwallet.kwalletmanager")
 
 public:
-    explicit KWalletManager(QWidget *parent = 0, const char *name = 0, Qt::WindowFlags f = 0);
+    explicit KWalletManager(QWidget *parent = nullptr, const QString &name = QString(), Qt::WindowFlags f = 0);
     virtual ~KWalletManager();
 
     void kwalletdLaunch();
@@ -55,7 +54,7 @@ public slots:
     void walletCreated(const QString &walletName);
 
 protected:
-    virtual bool queryClose();
+    bool queryClose() Q_DECL_OVERRIDE;
 
 private:
 public Q_SLOTS: //dbus
